@@ -375,8 +375,6 @@ archive_entry_determine_size (GVfsArchive          *archive,
 	    DEBUG ("archive_read_data_block: result = %d, error = '%s'\n", result, archive_error_string (archive->archive));
 	    archive_set_error (archive->archive, ARCHIVE_OK, "No error");
 	    archive_clear_error (archive->archive);
-            if (result == ARCHIVE_RETRY)
-              continue;
 	  }
 
 	  size += read;
@@ -542,8 +540,6 @@ create_file_tree (GVfsBackendArchive *ba, GVfsJob *job)
   	    DEBUG ("archive_read_next_header: result = %d, error = '%s'\n", result, archive_error_string (archive->archive));
   	    archive_set_error (archive->archive, ARCHIVE_OK, "No error");
   	    archive_clear_error (archive->archive);
-            if (result == ARCHIVE_RETRY)
-              continue;
 	  }
   
 	  ArchiveFile *file = archive_file_get_from_path (ba->files, 
@@ -729,8 +725,6 @@ do_open_for_read (GVfsBackend *       backend,
 	    DEBUG ("do_open_for_read: result = %d, error = '%s'\n", result, archive_error_string (archive->archive));
 	    archive_set_error (archive->archive, ARCHIVE_OK, "No error");
 	    archive_clear_error (archive->archive);
-            if (result == ARCHIVE_RETRY)
-              continue;
 	  }
 
           entry_pathname = archive_entry_pathname (entry);
